# Userset


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**this** | **object** | A DirectUserset is a sentinel message for referencing the direct members specified by an object/relation mapping. | [optional] 
**computed_userset** | [**ObjectRelation**](ObjectRelation.md) |  | [optional] 
**tuple_to_userset** | [**TupleToUserset**](TupleToUserset.md) |  | [optional] 
**union** | [**Usersets**](Usersets.md) |  | [optional] 
**intersection** | [**Usersets**](Usersets.md) |  | [optional] 
**difference** | [**Difference**](Difference.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


